library(sf)
library(ggplot)
library(lubridate)
library(zoo)
library(dplyr)
library(ggpubr)
library(rnaturalearth)
library(ggspatial)
library(viridis)
library(ggrepel)

# General settings ####
sf_use_s2(F)
wgs = "+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0"
ref_gsa = c("GSA12", "GSA13", "GSA14", "GSA15", "GSA16", 
            "GSA18", "GSA19", "GSA20", "GSA21", "GSA22", 
            "GSA23", "GSA24", "GSA25", "GSA26", "GSA27")
st_fun = function(x){
  (x-min(x, na.rm = T))/(max(x, na.rm = T)-min(x, na.rm = T))
}
# load spatial layers ####
# DW stratum
depth_polys = read_sf("maps/depth/DW_stratum.shp")
st_crs(depth_polys) = wgs
## GSAs
gsa = read_sf("maps/gsas/gsas.shp") %>%
  filter(SECT_COD %in% ref_gsa) %>%
  mutate(SECT_COD = factor(SECT_COD))
st_crs(gsa) = wgs
gsa_df = as.data.frame(gsa)
## land
map1 <- ne_countries(scale = 'medium', type = 'map_units',   returnclass = 'sf')
## grid
grid_area <- readRDS("maps/grid/DW_grid.rData")
st_crs(grid_area) = wgs

# load gridded data ####
## monthly fishing hours
effort = read.csv("data/effort/effort_dw_cen_est_med_2015-2018_monthly.csv") 
## trawling frequency 
frequency = read.csv("data/trawling_frequency/trawling_freq_dw_cen_est_med_2015-2018.csv") 

# base maps ####
## using ggrepl the position of label change every time the function is executed
base_plot1 = ggplot() + 
  geom_sf(data = map1, colour = NA, fill = "gray33") +
  geom_sf(data = depth_polys, colour = NA, fill = "gray66", size = 0.1) +
  geom_sf(data = gsa, fill = NA, size = 0.5) +
  geom_label_repel(data = gsa_df, aes(CENTER_X, CENTER_Y, label = SECT_COD), 
                   alpha = 0.6, nudge_x = sample(-10:10, length(unique(gsa$SECT_COD))),
                   nudge_y = sample(-15:15, length(unique(gsa$SECT_COD))), force = 1, force_pull = 0) +
  theme_minimal() +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        legend.position = "bottom")+
  coord_sf(xlim = c(9, 37), ylim = c(30, 42)) +
  annotation_scale(location = "tr", width_hint = 0.25, height = unit(0.15, "cm")) +
  annotation_north_arrow(location = "br", height = unit(.5, "cm"), width = unit(.5, "cm")) +
  xlab("") + ylab("")

base_plot1
saveRDS(base_plot1, "results/base_plot1.rData")

# same plot as before, but without ggrepel. Used for zooms on a specific area.
base_plot2 = ggplot() + 
  geom_sf(data = map1, colour = NA, fill = "gray33") +
  geom_sf(data = depth_polys, colour = NA, fill = "gray66", size = 0.1) +
  theme_minimal() +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        legend.position = "bottom") +
  coord_sf(xlim = c(9, 37), ylim = c(30, 42)) +
  xlab("") + ylab("")

base_plot2
saveRDS(base_plot2, "results/base_plot2.rData")

# Cumulative map ####
## estimate cumulative pattern on the whole period
effort_grid = effort %>%
  group_by(FID, GFCM_COD) %>%
  dplyr:::summarise(effort = sum(effort))

grid_effort = grid_area %>%
  inner_join(effort_grid)

## create scale value and label to use in legend
m_b = seq(min(log(grid_effort$effort)), max(log(grid_effort$effort)), length = 5)
m_l = round(exp(m_b))

base_plot1 = readRDS("results/base_plot1.rData")
plot_cumulative_study_area = base_plot1 +
  geom_sf(data = grid_effort, aes(fill = effort), colour = NA) +
  scale_fill_viridis(option="magma", trans = "log", labels = m_l, direction = -1) +
  guides(fill = guide_colorbar(title = "Fishing hours")) +
  theme(legend.key.width = unit(3, "cm")) +
  coord_sf(xlim = c(9, 37), ylim = c(30, 42)) +
  ggtitle("Cumulative fishing effort (2015-2018)")
plot_cumulative_study_area
ggsave("results/plot_cumulative_study_area.pdf", plot_cumulative_study_area, 
       width = 20, height = 15, units = "cm", dpi = 600, device = cairo_pdf)
knitr::plot_crop("results/plot_cumulative_study_area.pdf", quiet = TRUE)
bitmap <- pdftools::pdf_render_page("results/plot_cumulative_study_area.pdf", dpi = 600)
png::writePNG(bitmap, "results/plot_cumulative_study_area.png", asp = 16/9)
rm(bitmap); gc()

# Seasonal map ####
## estimate seasonal effort in a specific area (GSA23)
effort_grid_yq = effort %>%
  group_by(FID, GFCM_COD, GSA, quarter = quarter(date)) %>%
  dplyr:::summarise(effort = mean(effort)) %>%
  filter(GSA == "GSA23") %>%
  mutate(quarter = paste0("Q", quarter))

grid_effort_yq = grid_area %>%
  inner_join(effort_grid_yq) %>%
  mutate(effort_st = st_fun(effort))

## create scale value and label to use in legend
brks_out = seq(0, 1, length.out = 5)
brks_out_lab = round((brks_out*(max(grid_effort_yq$effort, na.rm = T) - min(grid_effort_yq$effort, na.rm = T))) + min(grid_effort_yq$effort_st, na.rm = T))


xbbox = st_bbox(gsa %>% filter(SECT_COD == "GSA23"))
base_plot2 = readRDS("results/base_plot2.rData")
plot_quarter_zoom = base_plot2 +
  geom_sf(data = grid_effort_yq, aes(fill = effort_st), colour = NA) +
  scale_fill_viridis(option="magma", direction = -1, label = brks_out_lab) +
  coord_sf(xlim = xbbox[c(1, 3)], ylim = xbbox[c(2, 4)]) +
  facet_wrap(~quarter, ncol = 1) +
  guides(fill = guide_colorbar(title = "Mean fishing hours")) +
  theme(legend.position = "right") +
  ggtitle("Seasonal effort in Crete (GSA23)") +
  annotation_scale(location = "bl", width_hint = 0.25, height = unit(0.15, "cm")) +
  annotation_north_arrow(location = "br", height = unit(.5, "cm"), width = unit(.5, "cm")) +
  theme(axis.text = element_text(size = 5))
plot_quarter_zoom
ggsave("results/plot_quarter_zoom_23.pdf", plot_quarter_zoom, width = 10, height = 15, units = "cm", dpi = 300, device = cairo_pdf)
knitr::plot_crop("results/plot_quarter_zoom_23.pdf", quiet = TRUE)
bitmap <- pdftools::pdf_render_page("results/plot_quarter_zoom_23.pdf", dpi = 600)
png::writePNG(bitmap, "results/plot_quarter_zoom_23.png")
rm(bitmap); gc()

# timeseries ####
effort_ym = effort %>%
  group_by(year, month, date) %>%
  dplyr:::summarise(effort = sum(effort))

peffrot_ym = ggplot() +
  geom_line(data = effort_ym, aes(date, effort, group = 1)) +
  geom_point(data = effort_ym, aes(date, effort), fill = "tomato1", shape = 21, size = 5) +
  theme_minimal() +
  theme(panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        axis.text = element_text(size = 15),
        title = element_text(size = 20)) +
  xlab("") + ylab("Hours") + ggtitle("Fishing Effort")
ggsave("results/effort_ym.png", peffrot_ym, width = 15, height = 5)

# Frequency  Map ####
## Study area - convert day in monthly range 
frequency_grid_yq = frequency %>%
  mutate(diff_days = as.numeric(as.character(diff_days))) %>%
  mutate(frequency = cut(diff_days, c(-Inf,89,179,364,729,Inf), labels = c( "<3", "3-6", "6-12", "12-24", ">24"))) %>%
  mutate(frequency = as.character(frequency)) %>%
  mutate(frequency_cl = factor(frequency, levels = c( "<3", "3-6", "6-12", "12-24", ">24")))

grid_freq = grid_area %>%
  inner_join(frequency_grid_yq)

xbbox = st_bbox(gsa)

plot_quarter_zoom_freq = base_plot2 +
  geom_sf(data = grid_freq, aes(fill = frequency_cl), colour = NA) +
  coord_sf(xlim = xbbox[c(1, 3)], ylim = xbbox[c(2, 4)]) +
  scale_fill_viridis(direction = 1, discrete = T) +
  guides(fill = guide_legend(title = "Months")) +
  ggtitle("Trawling frequency") +
  annotation_scale(location = "bl", width_hint = 0.25, height = unit(0.15, "cm")) +
  annotation_north_arrow(location = "br", height = unit(.5, "cm"), width = unit(.5, "cm")) +
  theme(axis.text = element_text(size = 5))
plot_quarter_zoom_freq
ggsave("results/plot_freq.pdf", plot_quarter_zoom_freq, width = 20, height = 15, units = "cm", dpi = 600, device = cairo_pdf)
knitr::plot_crop("results/plot_freq.pdf", quiet = TRUE)
bitmap <- pdftools::pdf_render_page("results/plot_freq.pdf", dpi = 600)
png::writePNG(bitmap, "results/plot_freq.png", asp = 16/9)
rm(bitmap); gc()


## Seasonal zoom freq - convert day in monthly range 
frequency_grid_yq = frequency %>%
  mutate(diff_days = as.numeric(as.character(diff_days))) %>%
  mutate(frequency = cut(diff_days, c(-Inf,89,179,364,729,Inf), labels = c( "<3", "3-6", "6-12", "12-24", ">24"))) %>%
  mutate(frequency = as.character(frequency)) %>%
  filter(GSA == "GSA23") %>%
  mutate(freq_cl = factor(frequency, levels = c( "<3", "3-6", "6-12", "12-24", ">24"))) %>%
  select(freq_cl, FID)

grid_freq = grid_area %>%
  inner_join(frequency_grid_yq)

xbbox = st_bbox(gsa %>% filter(SECT_COD == "GSA23"))

plot_quarter_zoom_freq = base_plot2 +
  geom_sf(data = grid_freq, aes(fill = freq_cl), colour = NA) +
  coord_sf(xlim = xbbox[c(1, 3)], ylim = xbbox[c(2, 4)]) +
  scale_fill_viridis(direction = 1, discrete = T) +
  guides(fill = guide_legend(title = "Months")) +
  ggtitle("Trawling frequency in Crete (GSA23)") +
  annotation_scale(location = "bl", width_hint = 0.25, height = unit(0.15, "cm")) +
  annotation_north_arrow(location = "br", height = unit(.5, "cm"), width = unit(.5, "cm")) +
  theme(axis.text = element_text(size = 5))
plot_quarter_zoom_freq
ggsave("results/plot_freq_23.pdf", plot_quarter_zoom_freq, width = 20, height = 15, units = "cm", dpi = 600, device = cairo_pdf)
knitr::plot_crop("results/plot_freq_23.pdf", quiet = TRUE)
bitmap <- pdftools::pdf_render_page("results/plot_freq_23.pdf", dpi = 600)
png::writePNG(bitmap, "results/plot_freq_23.png", asp = 16/9)
rm(bitmap); gc()


